.. SPDX-FileCopyrightText: 2020-2022 Simone Persiani <iosonopersia@gmail.com>
..
.. SPDX-License-Identifier: ISC

oc\_ocdm.graph package
======================

Modules
-------
.. toctree::
   :maxdepth: 1

   graph/oc_ocdm.graph.graph_entity
   graph/oc_ocdm.graph.graph_set

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   graph/oc_ocdm.graph.entities
